@@ -250,6 +250,8 @@ sub Reaper {
     processor => \&TransformTo,
     processor_params => ['em']
   };
+  $AllowElements->{'br'} = { #мы его потом превратим в параграф
+  };
   $AllowElements->{'u'} = {
     'allow_attributes' => [],
     processor => \&TransformTo,
@@ -273,6 +275,8 @@ sub Reaper {
   $AllowElements->{'h5'} = $AllowElements->{'h1'};
   $AllowElements->{'h6'} = $AllowElements->{'h1'};
 
+  my $Structure = $X->{'STRUCTURE'};
+  my $Description = $Structure->{'DESCRIPTION'};
   
 ###### счетчики, настройки, аккмуляторы и пр.
   $X->{'MaxMoveCount'} = 100; # максимальное кол-во символов принятия решения пустых <a id="good_link" href=""> на перенос 
@@ -334,14 +338,51 @@ sub Reaper {
   ) || $X->Error("Can't parse file ".$RootFile);
   $RootDoc->setEncoding('utf-8');
 
+  #ИЩЕМ Cover
+  my $CoverImg;
+  my $CheckIsCover=0;
+
+  #согласно epub.3 может быть в <item properties="cover-image"
+  if (my $CoverNode = $XC->findnodes('/root:package/root:manifest/root:item[@properties="cover-image"]',$RootDoc)->[0]) {
+    if ($CoverNode->getAttribute('media-type') =~ /^image\/(jpeg|png)$/) {
+      if ($CoverNode->getAttribute('href')) {
+        $CoverImg = $CoverNode->getAttribute('href');
+      }
+    }
+  }
+
+  #согласно epub.2 может быть в <meta name="cover"
+  if ( !$CoverImg && (my $CoverNode = $XC->findnodes('/root:package/root:metadata/root:meta[@name="cover"]',$RootDoc)->[0]) ) {
+    my $CoverID = $CoverNode->getAttribute('content');
+    if (my $CoverItem = $XC->findnodes('/root:package/root:manifest/root:item[@id="'.$CoverID.'"]',$RootDoc)->[0]) {
+      if ($CoverItem->getAttribute('media-type') =~ /^image\/(jpeg|png)$/) {
+        if ($CoverItem->getAttribute('href')) {
+          $CoverImg = $CoverItem->getAttribute('href');
+        }
+      }
+    }
+  }
+
   # список файлов с контентом
   my @Manifest;
   for my $MItem ($XC->findnodes('/root:package/root:manifest/root:item',$RootDoc)) {
+    my $ItemHref = $MItem->getAttribute('href');
+    my $ItemType = $MItem->getAttribute('media-type');
     push @Manifest, {
       'id' => $MItem->getAttribute('id'),
-      'href' => $MItem->getAttribute('href'),
-      'type' => $MItem->getAttribute('media-type'),
+      'href' => $ItemHref,
+      'type' => $ItemType,
     };
+
+    if ( # обложка не найдена? попробуем сами поискать
+      !$CoverImg
+      && $ItemHref =~ /cover/i
+      && $ItemType =~ /^image\/(jpeg|png)$/
+    ) { 
+      $CheckIsCover = 1; #способ хулиганский, поэтому будем проверять картинку
+      $CoverImg = $ItemHref;
+    }
+
   }
   my @Spine;
   for my $MItem ($XC->findnodes('/root:package/root:spine/root:itemref',$RootDoc)) {
@@ -349,6 +390,49 @@ sub Reaper {
     push @Spine, $IdRef;
   }
 
+  if ($CoverImg &&  1==1) {
+    $X->Msg("Try process cover image '$CoverImg'\n");
+   
+    my $SkipExists = 1;
+     my $CoverSrcFile = $X->RealPath(
+      FB3::Convert::dirname(
+        $X->{'ContentDir'}.'/'.$CoverImg
+      ).'/'.FB3::Convert::basename($CoverImg),
+    undef, $SkipExists);
+
+    $CoverSrcFile = CheckIsCover($X,$CoverSrcFile) if $CheckIsCover;
+
+    if (-f $CoverSrcFile && 1==3) {
+      my $ImgList = $X->{'STRUCTURE'}->{'IMG_LIST'};
+      my $CoverDestPath = $X->{'DestinationDir'}."/fb3/img";
+
+      $CoverImg =~ /.([^\/\.]+)$/;
+      my $ImgType = $1;
+
+      my $ImgID = 'img_'.$X->UUID($CoverSrcFile);
+      my $NewFileName = $ImgID.'.'.$ImgType;
+      my $CoverDestFile = $CoverDestPath.'/'.$NewFileName;
+
+      my $CoverDesc = {
+        'src_path' => $CoverSrcFile,
+        'new_path' => "img/".$NewFileName, #заменим на новое имя
+        'id' => $ImgID,
+      };
+
+      push @$ImgList, $CoverDesc unless grep {$_->{id} eq $ImgID} @$ImgList;
+      $Structure->{'DESCRIPTION'}->{'TITLE-INFO'}->{'COVER_DESC'} = $CoverDesc;
+
+      #Копируем исходник на новое место с новым уникальным именем
+      unless (-f $CoverDestFile) {
+        $X->Msg("copy $CoverSrcFile -> $CoverDestFile\n");
+        FB3::Convert::copy($CoverSrcFile, $CoverDestFile) or $X->Error($!." [copy $CoverSrcFile -> $CoverDestFile]");        
+       }
+      $X->Msg("Cover '$CoverImg' is OK\n");
+    }
+
+  }
+  #/cover
+
   $X->Msg("Assemble content\n");
   my $AC = AssembleContent($X, 'manifest' => \@Manifest, 'spine' => \@Spine);
 
@@ -357,9 +441,6 @@ sub Reaper {
   #Заполняем внутренний формат
 
   #МЕТА
-  my $Structure = $X->{'STRUCTURE'};
-  my $Description = $Structure->{'DESCRIPTION'};
-
   my $GlobalID;  
   unless (defined $Description->{'DOCUMENT-INFO'}->{'ID'}) { 
     $Description->{'DOCUMENT-INFO'}->{'ID'} = $GlobalID = $X->UUID();
@@ -1066,6 +1147,20 @@ sub AssembleContent {
 
 }
 
+sub CheckIsCover {
+  my $X = shift;
+  my $ImgSrcFile = shift;
+
+  my $ImgInfo = [Image::Size::imgsize($ImgSrcFile)];
+  my $W = $ImgInfo->[0] || return;
+  my $H = $ImgInfo->[1] || return;
+
+  my $Prop = $H/$W;
+  #img должен быть 1:1 - 1:5 и ширина 200+
+  return unless ($W>=200 && $Prop >=1 && $Prop <=5);
+  return $ImgSrcFile;
+}
+
 sub CleanTitle {
   my $X = shift;
   my $Node = shift;
@@ -1169,57 +1264,69 @@ sub ProcessImg {
     FB3::Convert::dirname($X->RealPath( $RelPath ? $X->{'ContentDir'}.'/'.$RelPath : $X->{'ContentDir'}, undef, $SkipExists)).'/'.$Src,
   undef,$SkipExists);
 
-  unless (-f $ImgSrcFile) { #не нашли картинку
-    $X->Msg("Can't find img".$ImgSrcFile." Replace to text [no image in epub file]\n","w");
-    my $Doc = XML::LibXML::Document->new('1.0', 'utf-8');
-    my $Text = $Doc->createTextNode('[no image in epub file]');
-    return $Text;
-  }
+  my $CoverIxists = $X->{'STRUCTURE'}->{'DESCRIPTION'}->{'TITLE-INFO'}->{'COVER_DESC'};
 
-  unless (exists $ImgChecked{$ImgSrcFile}) {
-    $X->_bs('img_info','Тип IMG');
-    my $ImgInfo;
-    my $ImgType;
-    if ($ImgSrcFile =~ /.svg$/) {
-      $ImgInfo = Image::ExifTool::ImageInfo($ImgSrcFile);
-      $ImgType = ref $ImgInfo eq 'HASH' ? $ImgInfo->{'FileType'} : undef;
-    } else {
-      $ImgInfo = [Image::Size::imgsize($ImgSrcFile)];
-      $ImgType = $ImgInfo->[2];
-    }
-    $X->_be('img_info');
+  my $ImgID;
 
-    if ( !$ImgType || !$X->isAllowedImageType($ImgType) ) { #неизвестный формат
-      $X->Msg("Can't detect img".$ImgSrcFile." Replace to text [bad img format]\n","w");
+  if (exists $CoverIxists->{'src_path'} && $CoverIxists->{'src_path'} eq $ImgSrcFile ) {
+    $ImgID = $CoverIxists->{'id'}; #уже отрабатывали картинку как cover, просто заменим src на готовый
+  } else {
+
+    unless (-f $ImgSrcFile) { #не нашли картинку
+      $X->Msg("Can't find img".$ImgSrcFile." Replace to text [no image in epub file]\n","w");
       my $Doc = XML::LibXML::Document->new('1.0', 'utf-8');
-      my $Text = $Doc->createTextNode('[bad img format]');
+      my $Text = $Doc->createTextNode('[no image in epub file]');
       return $Text;
+   }
+
+    unless (exists $ImgChecked{$ImgSrcFile}) {
+      $X->_bs('img_info','Тип IMG');
+      my $ImgInfo;
+      my $ImgType;
+      if ($ImgSrcFile =~ /.svg$/) {
+        $ImgInfo = Image::ExifTool::ImageInfo($ImgSrcFile);
+        $ImgType = ref $ImgInfo eq 'HASH' ? $ImgInfo->{'FileType'} : undef;
+      } else {
+        $ImgInfo = [Image::Size::imgsize($ImgSrcFile)];
+        $ImgType = $ImgInfo->[2];
+      }
+      $X->_be('img_info');
+
+      if ( !$ImgType || !$X->isAllowedImageType($ImgType) ) { #неизвестный формат
+        $X->Msg("Can't detect img".$ImgSrcFile." Replace to text [bad img format]\n","w");
+        my $Doc = XML::LibXML::Document->new('1.0', 'utf-8');
+        my $Text = $Doc->createTextNode('[bad img format]');
+        return $Text;
+      }
     }
-  }
-  $ImgChecked{$ImgSrcFile} = 1;
+    $ImgChecked{$ImgSrcFile} = 1;
 
-  $X->Msg("Find img, try transform: ".$Src."\n","w");
+    $X->Msg("Find img, try transform: ".$Src."\n","w");
 
-  my $ImgDestPath = $X->{'DestinationDir'}."/fb3/img";
+    my $ImgDestPath = $X->{'DestinationDir'}."/fb3/img";
 
-  $Src =~ /.([^\/\.]+)$/;
-  my $ImgType = $1;
+    $Src =~ /.([^\/\.]+)$/;
+    my $ImgType = $1;
 
-  my $ImgID = 'img_'.$X->UUID($ImgSrcFile);
-  my $NewFileName = $ImgID.'.'.$ImgType;
-  my $ImgDestFile = $ImgDestPath.'/'.$NewFileName;
+    $ImgID = 'img_'.$X->UUID($ImgSrcFile);
 
-  push @$ImgList, {
-    'new_path' => "img/".$NewFileName, #заменим на новое имя
-    'id' => $ImgID,
-  } unless grep {$_->{id} eq $ImgID} @$ImgList;
+    my $NewFileName = $ImgID.'.'.$ImgType;
+    my $ImgDestFile = $ImgDestPath.'/'.$NewFileName;
+
+    push @$ImgList, {
+      'src_path' => $ImgSrcFile,
+      'new_path' => "img/".$NewFileName, #заменим на новое имя
+      'id' => $ImgID,
+    } unless grep {$_->{id} eq $ImgID} @$ImgList;
+
+    #Копируем исходник на новое место с новым уникальным именем
+    unless (-f $ImgDestFile) {
+      $X->Msg("copy $ImgSrcFile -> $ImgDestFile\n");
+      $X->_bs('img_copy','Копирование IMG');
+      FB3::Convert::copy($ImgSrcFile, $ImgDestFile) or $X->Error($!." [copy $ImgSrcFile -> $ImgDestFile]");        
+      $X->_be('img_copy');
+    }
 
-  #Копируем исходник на новое место с новым уникальным именем
-  unless (-f $ImgDestFile) {
-    $X->Msg("copy $ImgSrcFile -> $ImgDestFile\n");
-    $X->_bs('img_copy','Копирование IMG');
-    FB3::Convert::copy($ImgSrcFile, $ImgDestFile) or $X->Error($!." [copy $ImgSrcFile -> $ImgDestFile]");        
-    $X->_be('img_copy');
   }
 
   $Node->setAttribute('src' => $ImgID);
@@ -1301,7 +1408,7 @@ sub FB3Creator {
   my $FB3Path = $X->{'DestinationDir'};
 
   #compile required files
-  my $CoverSrc = $Structure->{'DESCRIPTION'}->{'TITLE-INFO'}->{'COVER'};
+  my $CoverSrc = $Structure->{'DESCRIPTION'}->{'TITLE-INFO'}->{'COVER_DESC'}->{'new_path'};
 
   $X->Msg("FB3: Create /_rels/.rels\n","w");
   my $FNrels="$FB3Path/_rels/.rels";
@@ -1309,7 +1416,7 @@ sub FB3Creator {
   print FHrels qq{<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
   <Relationships xmlns="http://schemas.openxmlformats.org/package/2006/relationships">}.
   ( $CoverSrc ? qq{
-  <Relationship Id="rId0" Type="http://schemas.openxmlformats.org/package/2006/relationships/metadata/thumbnail" Target="$CoverSrc"/>} : '' ).qq{
+  <Relationship Id="rId0" Type="http://schemas.openxmlformats.org/package/2006/relationships/metadata/thumbnail" Target="fb3/$CoverSrc"/>} : '' ).qq{
   <Relationship Id="rId1" Type="http://schemas.openxmlformats.org/package/2006/relationships/metadata/core-properties" Target="fb3/meta/core.xml"/>
   <Relationship Id="rId2" Type="http://www.fictionbook.org/FictionBook3/relationships/Book" Target="fb3/description.xml"/>
   </Relationships>};
@@ -1396,7 +1503,9 @@ sub FB3Creator {
   }
 
   open FHbody, ">$FNbody" or $X->Error("$FNbody: $!");
-  print FHbody $Body->toString(1);
+  my $BodyString = $Body->toString(1);
+  $BodyString =~ s/<br\/>/<\/p><p>/g; #здесь уже правильный fb3, чистый и с параграфами, вот только <br/> нужно превратить в </p><p> 
+  print FHbody $BodyString;
   close FHbody;
 
   #Пишем мету
